@@ -12,16 +12,15 @@
 #    under the License.
 
 import datetime
+from unittest import mock
+from urllib import parse as urlparse
 
 from keystoneauth1 import exceptions as kc_exceptions
-import mock
 from oslo_utils import timeutils
-import six
-from six.moves.urllib import parse as urlparse
 
 from heat.common import exception
 from heat.common import template_format
-from heat.db.sqlalchemy import models
+from heat.db import models
 from heat.engine.clients.os import heat_plugin
 from heat.engine.clients.os.keystone import fake_keystoneclient as fake_ks
 from heat.engine.clients.os import swift
@@ -97,7 +96,7 @@ class SignalTest(common.HeatTestCase):
 
         tpl = template.Template(template_format.parse(template_string))
         ctx = utils.dummy_context()
-        ctx.tenant = 'test_tenant'
+        ctx.project_id = 'test_tenant'
         stack = stk.Stack(ctx, stack_name, tpl, disable_rollback=True)
         with utils.UUIDStub(stack_id):
             stack.store()
@@ -518,8 +517,7 @@ class SignalTest(common.HeatTestCase):
         # db resource concurrently, deleting it
 
         # Test exception not re-raised in DELETE case
-        res_obj = stack.context.session.query(
-            models.Resource).get(rsrc.id)
+        res_obj = stack.context.session.get(models.Resource, rsrc.id)
         res_obj.update({'action': 'DELETE'})
         rsrc._db_res_is_deleted = True
         rsrc._handle_signal(details=test_d)
@@ -627,7 +625,7 @@ class SignalTest(common.HeatTestCase):
         msg = 'Signal resource during %s is not supported.' % action
         exc = self.assertRaises(exception.NotSupported, rsrc.signal,
                                 details=err_metadata)
-        self.assertEqual(msg, six.text_type(exc))
+        self.assertEqual(msg, str(exc))
 
     def test_signal_in_delete_state(self):
         # assert that we get the correct exception when calling a
